# handyML

[![license](https://img.shields.io/github/license/leo6033/handyML)](LICENSE)

[英文文档](README.md)

## 目录

- [背景](#背景)
- [安装](#安装)
- [文档](#文档)
- [License](#License)

## 背景

一个封装数据挖掘竞赛中常用操作的库，包括EDA、Encoding、参数优化、模型训练、模型融合等。方便竞赛中代码复用，以及方便刚入门数据挖掘领域的朋友们学习。

## 安装

+ PyPI (pip):

> 

## 文档



## License

[MIT © Richard McRichface.](LICENSE)